<?php

namespace Apexl\Io\Component\Collections;

use Apexl\Io\Component\Components\Component;
use Apexl\Io\Component\Interfaces\ComponentInterface;
use Arrayy\Arrayy;
use Arrayy\Collection\AbstractCollection;

/**
 * @extends Arrayy<array-key, Component>
 * @method ComponentCollection add(Component $value, $key = null)
 */
final class ComponentCollection extends AbstractCollection
{
    public function getType(): string
    {
        return ComponentInterface::class;
    }
}
