<?php

declare(strict_types=1);

namespace Apexl\Io\Component\Services;

use Apexl\Io\Component\Components\Component;

class ComponentBucket extends Bucket
{
    public function set(string $name, Component $value): void
    {
        parent::_set($name, $value);
    }

    public function get(string $name): ?Component
    {
        return parent::_get($name);
    }
}
