<?php

namespace Apexl\Io\Component;

use Apexl\Io\Module;

/**
 * Base module file, provides required methods to register things like routes and middleware.
 * Class installModule
 * @package apexl\Io\modules\install
 */
readonly class ComponentModule extends Module
{
}
