<?php

namespace Apexl\Io\Component\Collections;

use Apexl\Io\Component\Components\ComponentProperty;
use Arrayy\Collection\AbstractCollection;

final class ComponentPropertyCollection extends AbstractCollection
{
    public function getType(): string
    {
        return ComponentProperty::class;
    }
}
